package
Version:
v1.1.3
Opens a new window with list of versions in this module.
Published: Jul 26, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Display struct {
X,
Y,
Width,
Height int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.